@@ -122,46 +122,21 @@ class Teacher(abstract.Teacher):
     def play_question(self):
         if self.q_status == self.QSTATUS_NO:
             return
-        instr_low, instr_low_vel, instr_high, instr_high_vel = self.get_instrument_config(2)
         low_tone = self.m_tonika.semitone_pitch()
         high_tone = (self.m_tonika+self.m_interval).semitone_pitch()
-
-        t1 = soundcard.Track()
-        t1.set_bpm(self.get_int('config/default_bpm'))
-        t1.set_patch(instr_low)
-        t1.start_note(low_tone, instr_low_vel)
-        t1.notelen_time(4)
-        t1.stop_note(low_tone, instr_low_vel)
-
-        t2 = soundcard.Track()
-        t1.set_bpm(self.get_int('config/default_bpm'))
-        t1.set_patch(instr_high)
-        t2.start_note(high_tone, instr_high_vel)
-        t2.notelen_time(4)
-        t2.stop_note(high_tone, instr_high_vel)
+        t1, t2 = utils.new_2_tracks()
+        t1.note(4, low_tone)
+        t2.note(4, high_tone)
         soundcard.synth.play_track(t1, t2)
         return 1
     def play_melodic(self):
         if self.q_status == self.QSTATUS_NO:
             return
-        if self.get_bool('config/override_default_instrument'):
-            instr_low = self.get_int('config/lowest_instrument')
-            instr_low_vel = self.get_int('config/lowest_instrument_velocity')
-            instr_high = self.get_int('config/highest_instrument')
-            instr_high_vel = self.get_int('config/highest_instrument_velocity')
-        else:
-            instr_low = instr_high = self.get_int('config/preferred_instrument')
-            instr_low_vel = instr_high_vel \
-                    = self.get_int('config/preferred_instrument_velocity')
-        low_tone = self.m_tonika.semitone_pitch()
-        high_tone = (self.m_tonika+self.m_interval).semitone_pitch()
-        m = soundcard.Track()
-        m.set_bpm(self.get_int('config/default_bpm'))
-        m.set_patch(instr_low)
-        m.note(4, low_tone, instr_low_vel)
-        m.set_patch(instr_high)
-        m.note(4, high_tone, instr_high_vel)
-        soundcard.synth.play_track(m)
+        t1, t2 = utils.new_2_tracks()
+        t1.note(4, self.m_tonika.semitone_pitch())
+        t2.note(4, 0, 0)
+        t2.note(4, (self.m_tonika + self.m_interval).semitone_pitch())
+        soundcard.synth.play_track(t1, t2)
     def start_practise(self):
         self.m_custom_mode = bool(not self.m_P.header.intervals)
         if self.m_P.header.intervals:
@@ -267,23 +242,15 @@ class Gui(abstract.IntervalGui):
         elif mouse_button == 2:
             # we only get here if you use one if the instrument widgets, not
             # with the buttons interface.
-            soundcard.play_note(self.get_int('config/preferred_instrument'),
-                          4, midi_int,
-                          self.get_int('config/preferred_instrument_velocity'))
+            # We call new_2_tracks here, because then t2 will have the
+            # instrument and velocity of the highest tone.
+            t1, t2 = utils.new_2_tracks()
+            t2.note(4, midi_int)
+            soundcard.synth.play_track(t2)
         elif mouse_button == 3 and self.m_t.q_status != self.QSTATUS_NO:
-            instr_low, instr_low_vel, instr_high, instr_high_vel = self.m_t.get_instrument_config(2)
-            n2 = self.m_t.m_tonika + interval
-            t1 = self.m_t.m_tonika + interval
-            t1 = soundcard.Track()
-            t1.set_patch(instr_low)
-            t1.start_note(self.m_t.m_tonika.semitone_pitch(), instr_low_vel)
-            t1.notelen_time(4)
-            t1.stop_note(self.m_t.m_tonika.semitone_pitch(), instr_high_vel)
-            t2 = soundcard.Track()
-            t2.set_patch(instr_high)
-            t2.start_note(n2.semitone_pitch(), instr_low_vel)
-            t2.notelen_time(4)
-            t2.stop_note(n2.semitone_pitch(), instr_high_vel)
+            t1, t2 = utils.new_2_tracks()
+            t1.note(4, self.m_t.m_tonika.semitone_pitch())
+            t2.note(4, (self.m_t.m_tonika + interval).semitone_pitch())
             soundcard.synth.play_track(t1, t2)
     def new_question(self, _o=None):
         """This function is called when you click on the 'New interval'
