@@ -17,7 +17,6 @@
 import gtk
 import abstract, idbyname, gu, statisticsviewer
 import soundcard, mpd, mpd.musicdisplayer
-import utils
 import lessonfile
 
 class Teacher(idbyname.Teacher):
@@ -35,7 +34,7 @@ class Gui(abstract.LessonbasedGui):
         ################
         # practise_box #
         ################
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
         self.practise_box.pack_start(self.g_music_displayer)
 
         self.g_flashbar = gu.FlashBar()
