@@ -17,6 +17,7 @@
 
 # Lesson file related GUI code.
 
+import warnings
 
 import gtk
 import locale
@@ -113,10 +114,11 @@ def new_labelobject(label):
         l.show()
     else:
         if isinstance(label, tuple):
-            # FIXME this _probably_never happens. I think only old code
+            # I think only old code
             # that has  been removed. But let us keep the code until
             # we have a chanse to review.
-            print "WARNING: lessonfilegui.new_labelobject: label is a tuple."
+            warnings.warn("lessonfilegui.new_labelobject: label is a tuple.",
+                          DeprecationWarning)
             labeltype, labeldata = label
         else:
             labeltype = label.m_labeltype
